@@ -1,10 +1,11 @@
+import os
 from os import sep
 from glob import glob
 import pandas as pd
 import numpy as np
-import bisect
 # from tqdm import tqdm
 from datetime import datetime, timedelta
+from microt_compliance_matrix import utils
 
 from microt_compliance_matrix.utils.uncompress_file import *
 
@@ -46,7 +47,7 @@ def validate_dates_before_after(intermediate_participant_path, date_in_study):
 
 def combine_intermediate_file(intermediate_participant_path, date_in_study, decryption_password):
     df_logs_combined = pd.DataFrame()
-    participant_id = extract_participant_id(intermediate_participant_path)
+    participant_id = utils.extract_participant_id.extract_participant_id(intermediate_participant_path)
 
     # generate date range where date folder exists (sharable code in utils)
     validated_date_list = validate_dates_before_after(intermediate_participant_path, date_in_study)
