@@ -123,10 +123,10 @@ def extract_reprompt(df_pr_phone):
 def clean_response_files(intermediate_participant_path, date_in_study, participant_id):
     # Check if date folder exists
     date_folder_path = os.path.join(intermediate_participant_path, date_in_study)
-    date_exist = validate_date(date_folder_path)
-    if not date_exist:
-        print("Cannot find date folder for {}".format(date_in_study))
-        raise Exception("Cannot find date folder for {}".format(date_in_study))
+    # date_exist = validate_date(date_folder_path)
+    # if not date_exist:
+    #     print("Cannot find date folder for {}".format(date_in_study))
+    #     raise Exception("Cannot find date folder for {}".format(date_in_study))
 
     # Check if phone_promptresponse file exists for this date
     csv_path = list(glob(os.path.join(date_folder_path, 'phone_promptresponse_clean*.csv')))
